pub enum CreateConstraintError {
EquivalentConstraintExists(String),
ConflictingConstraint(String),
DuplicateName(String),
DuplicateIndexName(String),
BackingIndexConflict(String),
UnsupportedPropertyType(String),
DataViolation(String),
Unsupported(&'static str),
}Variants
EquivalentConstraintExists(String)
22N65 — an equivalent constraint already exists.
ConflictingConstraint(String)
22N66 — a conflicting constraint already exists on the same schema.
DuplicateName(String)
22N67 — a constraint with the same name (any kind) already exists.
DuplicateIndexName(String)
22N71 — name collides with an existing index name.
BackingIndexConflict(String)
22N73 — uniqueness/key constraint would conflict with an existing range index on the same schema.
UnsupportedPropertyType(String)
22N90 — property type unsupported in constraint.
DataViolation(String)
50N11 — existing data already violates the proposed constraint.
Wraps the underlying crate::ConstraintViolation description.
Unsupported(&'static str)
Backend doesn’t support the catalog API.
Implementations
Sourceimpl CreateConstraintError
impl CreateConstraintError
pub const fn gql_status(&self) -> &'static str