pub struct IndexRequest {
pub explicit_name: Option<String>,
pub kind: StoredIndexKind,
pub entity: StoredIndexEntity,
pub label: Option<String>,
pub additional_labels: Vec<String>,
pub properties: Vec<String>,
pub options: BTreeMap<String, IndexConfigValue>,
}Expand description
What a caller asks the catalog to create. The explicit_name
is None when the user did not name the index at the call site —
the catalog will mint a deterministic one.
Fields
explicit_name: Option<String>kind: StoredIndexKindentity: StoredIndexEntitylabel: Option<String>additional_labels: Vec<String>Extra labels beyond label. Only populated for FULLTEXT requests.
properties: Vec<String>options: BTreeMap<String, IndexConfigValue>Trait Implementations
Sourceimpl Clone for IndexRequest
impl Clone for IndexRequest
Sourcefn clone(&self) -> IndexRequest
fn clone(&self) -> IndexRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexRequest
impl Debug for IndexRequest
Sourceimpl<'de> Deserialize<'de> for IndexRequest
impl<'de> Deserialize<'de> for IndexRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for IndexRequest
impl PartialEq for IndexRequest
Sourcefn eq(&self, other: &IndexRequest) -> bool
fn eq(&self, other: &IndexRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IndexRequest
impl Serialize for IndexRequest
impl StructuralPartialEq for IndexRequest