pub struct VectorIndexSnapshot {
pub name: String,
pub entity: StoredIndexEntity,
pub label: String,
pub property: String,
pub data: VectorBackendSnapshot,
}Expand description
Snapshot of one vector index, carried through the snapshot
pipeline. Only HNSW backends are persisted today (see
[VectorIndexRegistry::to_snapshots]); the enum is open for a
future Flat arm if pre-built flat backends become expensive to
rebuild for some workload.
Fields
name: Stringentity: StoredIndexEntitylabel: Stringproperty: Stringdata: VectorBackendSnapshotTrait Implementations
Sourceimpl Clone for VectorIndexSnapshot
impl Clone for VectorIndexSnapshot
Sourcefn clone(&self) -> VectorIndexSnapshot
fn clone(&self) -> VectorIndexSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VectorIndexSnapshot
impl Debug for VectorIndexSnapshot
Sourceimpl<'de> Deserialize<'de> for VectorIndexSnapshot
impl<'de> Deserialize<'de> for VectorIndexSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for VectorIndexSnapshot
impl PartialEq for VectorIndexSnapshot
Sourcefn eq(&self, other: &VectorIndexSnapshot) -> bool
fn eq(&self, other: &VectorIndexSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VectorIndexSnapshot
impl Serialize for VectorIndexSnapshot
impl StructuralPartialEq for VectorIndexSnapshot